timetokentools.TupletMonadTimeTokenMaker
========================================

.. inheritance-diagram:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker
   :private-bases:

.. autoclass:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.reverse

    Inherited from :py:class:`timetokentools.TimeTokenMaker <abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker>`

Special Methods
---------------

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__call__

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.TupletMonadTimeTokenMaker.__repr__

    Inherited from :py:class:`timetokentools.TimeTokenMaker <abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker>`
